package org.apache.commons.lang3;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectStreamClass;
import java.util.HashMap;
import java.util.Map;
import org.apache.commons.lang3.SerializationUtils;

class ClassLoaderAwareObjectInputStream extends ObjectInputStream {
  private static final Map<String, Class<?>> primitiveTypes = new HashMap<>();
  
  private final ClassLoader classLoader;
  
  static {
    primitiveTypes.put("byte", byte.class);
    primitiveTypes.put("short", short.class);
    primitiveTypes.put("int", int.class);
    primitiveTypes.put("long", long.class);
    primitiveTypes.put("float", float.class);
    primitiveTypes.put("double", double.class);
    primitiveTypes.put("boolean", boolean.class);
    primitiveTypes.put("char", char.class);
    primitiveTypes.put("void", void.class);
  }
  
  ClassLoaderAwareObjectInputStream(InputStream in, ClassLoader classLoader) throws IOException {
    super(in);
    this.classLoader = classLoader;
  }
  
  protected Class<?> resolveClass(ObjectStreamClass desc) throws IOException, ClassNotFoundException {
    String name = desc.getName();
    try {
      return Class.forName(name, false, this.classLoader);
    } catch (ClassNotFoundException ex) {
      try {
        return Class.forName(name, false, Thread.currentThread().getContextClassLoader());
      } catch (ClassNotFoundException cnfe) {
        Class<?> cls = primitiveTypes.get(name);
        if (cls != null)
          return cls; 
        throw cnfe;
      } 
    } 
  }
}
